@@ -45,6 +45,8 @@ class PlexPartialObject(object):
 
 def cast(func, value):
     if value not in [None, NA]:
+        if func == bool:
+            value = int(value)
         value = func(value)
     return value
 
